@@ -1,4 +1,4 @@
-from .hyperstate import HyperState, load, loads, dump, dumps
+from .hyperstate import StateManager, load, loads, dump, dumps
 from .lazy import Serializable, Lazy, blob
 from .schema.versioned import Versioned
 from .schema.schema_checker import schema_evolution_cli
@@ -6,7 +6,7 @@ from .schema.help import help
 from .command import command, stateful_command
 
 __all__ = [
-    "HyperState",
+    "StateManager",
     "load",
     "loads",
     "dump",
