@@ -49,7 +49,7 @@ class StateManager(Generic[C, S]):
         config_cls: Type[C],
         state_cls: Type[S],
         initial_state: Callable[[C, Dict[str, Any]], S],
-        init_path: Union[str, Path, None],
+        init_path: Union[str, Path, None] = None,
         checkpoint_dir: Union[str, Path, None] = None,
         overrides: Optional[List[str]] = None,
         ignore_extra_fields: bool = False,
@@ -133,7 +133,7 @@ class StateManager(Generic[C, S]):
             self.config_cls,
             file=path,
             overrides=self.overrides or [],
-            allow_missing_version=path is None,
+            allow_missing_version=path is None or not isinstance(self.config_cls, Versioned),
             ignore_extra_fields=self.ignore_extra_fields,
         )
 
